/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package com.supinfo.spitfireboard.jpa;

import com.supinfo.spitfireboard.dao.UserDao;
import com.supinfo.spitfireboard.entities.User;
import java.util.Date;
import java.util.List;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;

/**
 *
 * @author Fabien LOISON
 */
@Stateless
public class JpaUserDao implements UserDao {
    @PersistenceContext
    private EntityManager em;
    
    @Override
    public User getById(Long id) {
        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<User> query = builder.createQuery(User.class);
        Root<User> user = query.from(User.class);
        query.where(builder.equal(user.get("id"), id));
        return em.createQuery(query).getSingleResult();
    }
    
    @Override
    public User getByUserName(String userName) {
        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<User> query = builder.createQuery(User.class);
        Root<User> user = query.from(User.class);
        query.where(builder.equal(user.get("userName"), userName));
        List<User> users = em.createQuery(query).getResultList();
        if (!users.isEmpty()) {
            return users.get(0);
        }
        return null;
    }
    
    @Override
    public List<User> getAll() {
        CriteriaBuilder builder = em.getCriteriaBuilder();
        CriteriaQuery<User> query = builder.createQuery(User.class);
        query.from(User.class);
        return em.createQuery(query).getResultList();
    }
    
    @Override
    public void insertUser(String userName, String email, String password, String avatar, Integer userRole, Date registrationDate) {
        User user = new User();
        
        user.setUserName(userName);
        user.setEmail(email);
        user.setPassword(password);
        user.setAvatar(avatar);
        user.setUserRole(userRole);
        user.setRegistrationDate(registrationDate);
        
        em.persist(user);
    }
    
    @Override
    public Long persistUser(User user) {
        em.persist(user);
        em.flush();
        return user.getId();
    } 
    
    @Override
    public void delete(Long id) {
        User user = this.getById(id);
        em.remove(user);
    }
}
